Function frame_system::extrinsics_data_root [−][src]
pub fn extrinsics_data_root<H: Hash>(xts: Vec<Vec<u8>>) -> H::OutputExpand description
Compute the trie root of a list of extrinsics.
pub fn extrinsics_data_root<H: Hash>(xts: Vec<Vec<u8>>) -> H::OutputCompute the trie root of a list of extrinsics.