Struct frame_system::limits::BlockWeights [−][src]
pub struct BlockWeights {
pub base_block: Weight,
pub max_block: Weight,
pub per_class: PerDispatchClass<WeightsPerClass>,
}Expand description
Block weight limits & base values configuration.
This object is responsible for defining weight limits and base weight values tracked during extrinsic execution.
Each block starts with base_block weight being consumed right away. Next up the
on_initialize pallet callbacks are invoked and their cost is added before any extrinsic
is executed. This cost is tracked as Mandatory dispatch class.
| | `max_block` | |
| | | |
| | | |
| | | |
| | | #| `on_initialize`
| #| `base_block` | #|
|NOM| |NOM|
||\_ Mandatory
|\__ Operational
\___ NormalThe remaining capacity can be used to dispatch extrinsics. Note that each dispatch class
is being tracked separately, but the sum can’t exceed max_block (except for reserved).
Below you can see a picture representing full block with 3 extrinsics (two Operational and
one Normal). Each class has it’s own limit max_total, but also the sum cannot exceed
max_block value.
-- `Mandatory` limit (unlimited)
| # | | |
| # | `Ext3` | - - `Operational` limit
|# | `Ext2` |- - `Normal` limit
| # | `Ext1` | # |
| #| `on_initialize` | ##|
| #| `base_block` |###|
|NOM| |NOM|It should be obvious now that it’s possible for one class to reach it’s limit (say Normal),
while the block has still capacity to process more transactions (max_block not reached,
Operational transactions can still go in). Setting max_total to None disables the
per-class limit. This is generally highly recommended for Mandatory dispatch class, while it
can be dangerous for Normal class and should only be done with extra care and consideration.
Often it’s desirable for some class of transactions to be added to the block despite it being
full. For instance one might want to prevent high-priority Normal transactions from pushing
out lower-priority Operational transactions. In such cases you might add a reserved capacity
for given class.
_
| # | `Ext7 | - - `Operational` limit
|# | `Ext6` | |
|# | `Ext5` |-# - `Normal` limit
|# | `Ext4` |## |
| #| `on_initialize` |###|
| #| `base_block` |###|
|NOM| |NOM|In the above example, Ext4-6 fill up the block almost up to max_block. Ext7 would not fit
if there wasn’t the extra reserved space for Operational transactions. Note that max_total
limit applies to reserved space as well (i.e. the sum of weights of Ext7 & Ext8 mustn’t
exceed it). Setting reserved to None allows the extrinsics to always get into the block up
to their max_total limit. If max_total is set to None as well, all extrinsics witch
dispatchables of given class will always end up in the block (recommended for Mandatory
dispatch class).
As a consequence of reserved space, total consumed block weight might exceed max_block
value, so this parameter should rather be thought of as “target block weight” than a hard limit.
Fields
base_block: WeightBase weight of block execution.
max_block: WeightMaximal total weight consumed by all kinds of extrinsics (without reserved space).
per_class: PerDispatchClass<WeightsPerClass>Weight limits for extrinsics of given dispatch class.
Implementations
Get per-class weight settings.
Verifies correctness of this BlockWeights object.
Create new weights definition, with both Normal and Operational
classes limited to given weight.
Note there is no reservation for Operational class, so this constructor
is not suitable for production deployments.
Create a sensible default weights system given only expected maximal block weight and the
ratio that Normal extrinsics should occupy.
Assumptions:
- Average block initialization is assumed to be
10%. Operationaltransactions have reserved allowance (1.0 - normal_ratio)
Start constructing new BlockWeights object.
By default all kinds except of Mandatory extrinsics are disallowed.