Struct frame_system::limits::BlockWeightsBuilder [−][src]
pub struct BlockWeightsBuilder { /* fields omitted */ }Expand description
An opinionated builder for Weights object.
Implementations
Set base block weight.
Average block initialization weight cost.
This value is used to derive maximal allowed extrinsic weight for each class, based on the allowance.
This is to make sure that extrinsics don’t stay forever in the pool,
because they could seamingly fit the block (since they are below max_block),
but the cost of calling on_initialize alway prevents them from being included.
pub fn for_class(
self,
class: impl OneOrMany<DispatchClass>,
action: impl Fn(&mut WeightsPerClass)
) -> Self
pub fn for_class(
self,
class: impl OneOrMany<DispatchClass>,
action: impl Fn(&mut WeightsPerClass)
) -> Self
Set parameters for particular class.
Note: None values of max_extrinsic will be overwritten in build in case
avg_block_initialization rate is set to a non-zero value.
Construct the BlockWeights object.
Construct the BlockWeights object or panic if it’s invalid.
This is a convenience method to be called whenever you construct a runtime.