Struct frame_system::CheckWeight [−][src]
Block resource (weight) limit check.
Transaction Validity
This extension does not influence any fields of TransactionValidity in case the
transaction is valid.
Implementations
impl<T: Config + Send + Sync> CheckWeight<T> where
T::Call: Dispatchable<Info = DispatchInfo, PostInfo = PostDispatchInfo>,
impl<T: Config + Send + Sync> CheckWeight<T> where
T::Call: Dispatchable<Info = DispatchInfo, PostInfo = PostDispatchInfo>,
pub fn do_pre_dispatch(
info: &DispatchInfoOf<T::Call>,
len: usize
) -> Result<(), TransactionValidityError>
pub fn do_pre_dispatch(
info: &DispatchInfoOf<T::Call>,
len: usize
) -> Result<(), TransactionValidityError>
Do the pre-dispatch checks. This can be applied to both signed and unsigned.
It checks and notes the new weight and length.
Do the validate checks. This can be applied to both signed and unsigned.
It only checks that the block weight and length limit will not exceed.